@@ -9,21 +9,38 @@
 #' * `bar_plot2()` creates the 2nd barplot of the ranks of genotypes
 #' using the `graphics` package.
 #' @param datap The data set
+#' @param lowt A parameter indicating whether lower rates of the trait
+#' is preferred or not. For grain yield e.g. Upper values is preferred. For plant height
+#' lower values e.g. is preferred.
 #' @param verbose If `verbose = TRUE` then some results are printed
 #' @importFrom graphics barplot par text
 #' @return Returns an object of class `gg, graphics`
-#' @usage bar_plot2(datap, verbose = FALSE)
+#' @usage bar_plot2(datap, lowt = FALSE, verbose = FALSE)
 #'
 #' @examples
+#' # Case 1:  Higher trait values are preferred. For instance grain yield
+#' # in cereals is a trait which its higher values are preferred and ranking
+#' # is performed from the higher to lower values i.e. 1st, 2nd, 3rd etc
+#' # in maize dataset.
 #' \donttest{
 #' data(maize)
-#' bar_plot2(maize, verbose = FALSE)
+#' bar_plot2(maize) # or: bar_plot2(maize, lowt = FALSE, verbose = FALSE)
+#' }
+#' @examples
+#' # Case 2:  In this case, the lower values of the given trait are preferred.
+#' # For instance days to maturity (dm) and plant height are traits where their
+#' # lower values are preferred.
+#' \donttest{
+#' data(dm)
+#' bar_plot2(dm, lowt = TRUE, verbose = TRUE)
 #' }
 #' @export
 
-bar_plot2 <- function(datap, verbose = FALSE)
+bar_plot2 <- function(datap, lowt = FALSE, verbose = FALSE)
 {
-  datap <- ranki(datap)
+  if (lowt) {
+    datap <- ranki(datap, lowt = TRUE) } else {
+      datap <- ranki(datap) }
 
   A <- datap$rYWAASB
   B <- datap$GEN
